==> dqops-0.2.0.5-py2.py3-none-any.whl: dqops/client/models/table_sql_daily_partitioned_checks_spec.py <==
from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.table_sql_aggregate_expr_check_spec import (
        TableSqlAggregateExprCheckSpec,
    )
    from ..models.table_sql_condition_failed_count_check_spec import (
        TableSqlConditionFailedCountCheckSpec,
    )
    from ..models.table_sql_condition_passed_percent_check_spec import (
        TableSqlConditionPassedPercentCheckSpec,
    )


T = TypeVar("T", bound="TableSqlDailyPartitionedChecksSpec")


@attr.s(auto_attribs=True)
class TableSqlDailyPartitionedChecksSpec:
    """
    Attributes:
        daily_partition_sql_condition_passed_percent_on_table (Union[Unset, TableSqlConditionPassedPercentCheckSpec]):
        daily_partition_sql_condition_failed_count_on_table (Union[Unset, TableSqlConditionFailedCountCheckSpec]):
        daily_partition_sql_aggregate_expr_table (Union[Unset, TableSqlAggregateExprCheckSpec]):
        min_sql_condition_passed_percent_on_table (Union[Unset, TableSqlConditionPassedPercentCheckSpec]):
    """

    daily_partition_sql_condition_passed_percent_on_table: Union[
        Unset, "TableSqlConditionPassedPercentCheckSpec"
    ] = UNSET
    daily_partition_sql_condition_failed_count_on_table: Union[
        Unset, "TableSqlConditionFailedCountCheckSpec"
    ] = UNSET
    daily_partition_sql_aggregate_expr_table: Union[
        Unset, "TableSqlAggregateExprCheckSpec"
    ] = UNSET
    min_sql_condition_passed_percent_on_table: Union[
        Unset, "TableSqlConditionPassedPercentCheckSpec"
    ] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        daily_partition_sql_condition_passed_percent_on_table: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(
            self.daily_partition_sql_condition_passed_percent_on_table, Unset
        ):
            daily_partition_sql_condition_passed_percent_on_table = (
                self.daily_partition_sql_condition_passed_percent_on_table.to_dict()
            )

        daily_partition_sql_condition_failed_count_on_table: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(
            self.daily_partition_sql_condition_failed_count_on_table, Unset
        ):
            daily_partition_sql_condition_failed_count_on_table = (
                self.daily_partition_sql_condition_failed_count_on_table.to_dict()
            )

        daily_partition_sql_aggregate_expr_table: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.daily_partition_sql_aggregate_expr_table, Unset):
            daily_partition_sql_aggregate_expr_table = (
                self.daily_partition_sql_aggregate_expr_table.to_dict()
            )

        min_sql_condition_passed_percent_on_table: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.min_sql_condition_passed_percent_on_table, Unset):
            min_sql_condition_passed_percent_on_table = (
                self.min_sql_condition_passed_percent_on_table.to_dict()
            )

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if daily_partition_sql_condition_passed_percent_on_table is not UNSET:
            field_dict[
                "daily_partition_sql_condition_passed_percent_on_table"
            ] = daily_partition_sql_condition_passed_percent_on_table
        if daily_partition_sql_condition_failed_count_on_table is not UNSET:
            field_dict[
                "daily_partition_sql_condition_failed_count_on_table"
            ] = daily_partition_sql_condition_failed_count_on_table
        if daily_partition_sql_aggregate_expr_table is not UNSET:
            field_dict[
                "daily_partition_sql_aggregate_expr_table"
            ] = daily_partition_sql_aggregate_expr_table
        if min_sql_condition_passed_percent_on_table is not UNSET:
            field_dict[
                "min_sql_condition_passed_percent_on_table"
            ] = min_sql_condition_passed_percent_on_table

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.table_sql_aggregate_expr_check_spec import (
            TableSqlAggregateExprCheckSpec,
        )
        from ..models.table_sql_condition_failed_count_check_spec import (
            TableSqlConditionFailedCountCheckSpec,
        )
        from ..models.table_sql_condition_passed_percent_check_spec import (
            TableSqlConditionPassedPercentCheckSpec,
        )

        d = src_dict.copy()
        _daily_partition_sql_condition_passed_percent_on_table = d.pop(
            "daily_partition_sql_condition_passed_percent_on_table", UNSET
        )
        daily_partition_sql_condition_passed_percent_on_table: Union[
            Unset, TableSqlConditionPassedPercentCheckSpec
        ]
        if isinstance(_daily_partition_sql_condition_passed_percent_on_table, Unset):
            daily_partition_sql_condition_passed_percent_on_table = UNSET
        else:
            daily_partition_sql_condition_passed_percent_on_table = (
                TableSqlConditionPassedPercentCheckSpec.from_dict(
                    _daily_partition_sql_condition_passed_percent_on_table
                )
            )

        _daily_partition_sql_condition_failed_count_on_table = d.pop(
            "daily_partition_sql_condition_failed_count_on_table", UNSET
        )
        daily_partition_sql_condition_failed_count_on_table: Union[
            Unset, TableSqlConditionFailedCountCheckSpec
        ]
        if isinstance(_daily_partition_sql_condition_failed_count_on_table, Unset):
            daily_partition_sql_condition_failed_count_on_table = UNSET
        else:
            daily_partition_sql_condition_failed_count_on_table = (
                TableSqlConditionFailedCountCheckSpec.from_dict(
                    _daily_partition_sql_condition_failed_count_on_table
                )
            )

        _daily_partition_sql_aggregate_expr_table = d.pop(
            "daily_partition_sql_aggregate_expr_table", UNSET
        )
        daily_partition_sql_aggregate_expr_table: Union[
            Unset, TableSqlAggregateExprCheckSpec
        ]
        if isinstance(_daily_partition_sql_aggregate_expr_table, Unset):
            daily_partition_sql_aggregate_expr_table = UNSET
        else:
            daily_partition_sql_aggregate_expr_table = (
                TableSqlAggregateExprCheckSpec.from_dict(
                    _daily_partition_sql_aggregate_expr_table
                )
            )

        _min_sql_condition_passed_percent_on_table = d.pop(
            "min_sql_condition_passed_percent_on_table", UNSET
        )
        min_sql_condition_passed_percent_on_table: Union[
            Unset, TableSqlConditionPassedPercentCheckSpec
        ]
        if isinstance(_min_sql_condition_passed_percent_on_table, Unset):
            min_sql_condition_passed_percent_on_table = UNSET
        else:
            min_sql_condition_passed_percent_on_table = (
                TableSqlConditionPassedPercentCheckSpec.from_dict(
                    _min_sql_condition_passed_percent_on_table
                )
            )

        table_sql_daily_partitioned_checks_spec = cls(
            daily_partition_sql_condition_passed_percent_on_table=daily_partition_sql_condition_passed_percent_on_table,
            daily_partition_sql_condition_failed_count_on_table=daily_partition_sql_condition_failed_count_on_table,
            daily_partition_sql_aggregate_expr_table=daily_partition_sql_aggregate_expr_table,
            min_sql_condition_passed_percent_on_table=min_sql_condition_passed_percent_on_table,
        )

        table_sql_daily_partitioned_checks_spec.additional_properties = d
        return table_sql_daily_partitioned_checks_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> dqops-0.3.0-py2.py3-none-any.whl: dqops/client/models/table_sql_daily_partitioned_checks_spec.py <==
from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.table_sql_aggregate_expr_check_spec import (
        TableSqlAggregateExprCheckSpec,
    )
    from ..models.table_sql_condition_failed_count_check_spec import (
        TableSqlConditionFailedCountCheckSpec,
    )
    from ..models.table_sql_condition_passed_percent_check_spec import (
        TableSqlConditionPassedPercentCheckSpec,
    )
    from ..models.table_sql_daily_partitioned_checks_spec_custom_checks import (
        TableSqlDailyPartitionedChecksSpecCustomChecks,
    )


T = TypeVar("T", bound="TableSqlDailyPartitionedChecksSpec")


@_attrs_define
class TableSqlDailyPartitionedChecksSpec:
    """
    Attributes:
        custom_checks (Union[Unset, TableSqlDailyPartitionedChecksSpecCustomChecks]): Dictionary of additional custom
            checks within this category. The keys are check names defined in the definition section. The sensor parameters
            and rules should match the type of the configured sensor and rule for the custom check.
        daily_partition_sql_condition_passed_percent_on_table (Union[Unset, TableSqlConditionPassedPercentCheckSpec]):
        daily_partition_sql_condition_failed_count_on_table (Union[Unset, TableSqlConditionFailedCountCheckSpec]):
        daily_partition_sql_aggregate_expr_table (Union[Unset, TableSqlAggregateExprCheckSpec]):
        min_sql_condition_passed_percent_on_table (Union[Unset, TableSqlConditionPassedPercentCheckSpec]):
    """

    custom_checks: Union[
        Unset, "TableSqlDailyPartitionedChecksSpecCustomChecks"
    ] = UNSET
    daily_partition_sql_condition_passed_percent_on_table: Union[
        Unset, "TableSqlConditionPassedPercentCheckSpec"
    ] = UNSET
    daily_partition_sql_condition_failed_count_on_table: Union[
        Unset, "TableSqlConditionFailedCountCheckSpec"
    ] = UNSET
    daily_partition_sql_aggregate_expr_table: Union[
        Unset, "TableSqlAggregateExprCheckSpec"
    ] = UNSET
    min_sql_condition_passed_percent_on_table: Union[
        Unset, "TableSqlConditionPassedPercentCheckSpec"
    ] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        custom_checks: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.custom_checks, Unset):
            custom_checks = self.custom_checks.to_dict()

        daily_partition_sql_condition_passed_percent_on_table: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(
            self.daily_partition_sql_condition_passed_percent_on_table, Unset
        ):
            daily_partition_sql_condition_passed_percent_on_table = (
                self.daily_partition_sql_condition_passed_percent_on_table.to_dict()
            )

        daily_partition_sql_condition_failed_count_on_table: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(
            self.daily_partition_sql_condition_failed_count_on_table, Unset
        ):
            daily_partition_sql_condition_failed_count_on_table = (
                self.daily_partition_sql_condition_failed_count_on_table.to_dict()
            )

        daily_partition_sql_aggregate_expr_table: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.daily_partition_sql_aggregate_expr_table, Unset):
            daily_partition_sql_aggregate_expr_table = (
                self.daily_partition_sql_aggregate_expr_table.to_dict()
            )

        min_sql_condition_passed_percent_on_table: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.min_sql_condition_passed_percent_on_table, Unset):
            min_sql_condition_passed_percent_on_table = (
                self.min_sql_condition_passed_percent_on_table.to_dict()
            )

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if custom_checks is not UNSET:
            field_dict["custom_checks"] = custom_checks
        if daily_partition_sql_condition_passed_percent_on_table is not UNSET:
            field_dict[
                "daily_partition_sql_condition_passed_percent_on_table"
            ] = daily_partition_sql_condition_passed_percent_on_table
        if daily_partition_sql_condition_failed_count_on_table is not UNSET:
            field_dict[
                "daily_partition_sql_condition_failed_count_on_table"
            ] = daily_partition_sql_condition_failed_count_on_table
        if daily_partition_sql_aggregate_expr_table is not UNSET:
            field_dict[
                "daily_partition_sql_aggregate_expr_table"
            ] = daily_partition_sql_aggregate_expr_table
        if min_sql_condition_passed_percent_on_table is not UNSET:
            field_dict[
                "min_sql_condition_passed_percent_on_table"
            ] = min_sql_condition_passed_percent_on_table

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.table_sql_aggregate_expr_check_spec import (
            TableSqlAggregateExprCheckSpec,
        )
        from ..models.table_sql_condition_failed_count_check_spec import (
            TableSqlConditionFailedCountCheckSpec,
        )
        from ..models.table_sql_condition_passed_percent_check_spec import (
            TableSqlConditionPassedPercentCheckSpec,
        )
        from ..models.table_sql_daily_partitioned_checks_spec_custom_checks import (
            TableSqlDailyPartitionedChecksSpecCustomChecks,
        )

        d = src_dict.copy()
        _custom_checks = d.pop("custom_checks", UNSET)
        custom_checks: Union[Unset, TableSqlDailyPartitionedChecksSpecCustomChecks]
        if isinstance(_custom_checks, Unset):
            custom_checks = UNSET
        else:
            custom_checks = TableSqlDailyPartitionedChecksSpecCustomChecks.from_dict(
                _custom_checks
            )

        _daily_partition_sql_condition_passed_percent_on_table = d.pop(
            "daily_partition_sql_condition_passed_percent_on_table", UNSET
        )
        daily_partition_sql_condition_passed_percent_on_table: Union[
            Unset, TableSqlConditionPassedPercentCheckSpec
        ]
        if isinstance(_daily_partition_sql_condition_passed_percent_on_table, Unset):
            daily_partition_sql_condition_passed_percent_on_table = UNSET
        else:
            daily_partition_sql_condition_passed_percent_on_table = (
                TableSqlConditionPassedPercentCheckSpec.from_dict(
                    _daily_partition_sql_condition_passed_percent_on_table
                )
            )

        _daily_partition_sql_condition_failed_count_on_table = d.pop(
            "daily_partition_sql_condition_failed_count_on_table", UNSET
        )
        daily_partition_sql_condition_failed_count_on_table: Union[
            Unset, TableSqlConditionFailedCountCheckSpec
        ]
        if isinstance(_daily_partition_sql_condition_failed_count_on_table, Unset):
            daily_partition_sql_condition_failed_count_on_table = UNSET
        else:
            daily_partition_sql_condition_failed_count_on_table = (
                TableSqlConditionFailedCountCheckSpec.from_dict(
                    _daily_partition_sql_condition_failed_count_on_table
                )
            )

        _daily_partition_sql_aggregate_expr_table = d.pop(
            "daily_partition_sql_aggregate_expr_table", UNSET
        )
        daily_partition_sql_aggregate_expr_table: Union[
            Unset, TableSqlAggregateExprCheckSpec
        ]
        if isinstance(_daily_partition_sql_aggregate_expr_table, Unset):
            daily_partition_sql_aggregate_expr_table = UNSET
        else:
            daily_partition_sql_aggregate_expr_table = (
                TableSqlAggregateExprCheckSpec.from_dict(
                    _daily_partition_sql_aggregate_expr_table
                )
            )

        _min_sql_condition_passed_percent_on_table = d.pop(
            "min_sql_condition_passed_percent_on_table", UNSET
        )
        min_sql_condition_passed_percent_on_table: Union[
            Unset, TableSqlConditionPassedPercentCheckSpec
        ]
        if isinstance(_min_sql_condition_passed_percent_on_table, Unset):
            min_sql_condition_passed_percent_on_table = UNSET
        else:
            min_sql_condition_passed_percent_on_table = (
                TableSqlConditionPassedPercentCheckSpec.from_dict(
                    _min_sql_condition_passed_percent_on_table
                )
            )

        table_sql_daily_partitioned_checks_spec = cls(
            custom_checks=custom_checks,
            daily_partition_sql_condition_passed_percent_on_table=daily_partition_sql_condition_passed_percent_on_table,
            daily_partition_sql_condition_failed_count_on_table=daily_partition_sql_condition_failed_count_on_table,
            daily_partition_sql_aggregate_expr_table=daily_partition_sql_aggregate_expr_table,
            min_sql_condition_passed_percent_on_table=min_sql_condition_passed_percent_on_table,
        )

        table_sql_daily_partitioned_checks_spec.additional_properties = d
        return table_sql_daily_partitioned_checks_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
